# `Marker` Component API

## Props

| Prop Name <br/> and Type                    | Notes                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| ------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `title:` <br/> `string`                     | The title of the marker. This is only used if the <Marker /> component has no children that are a `<Callout />`, in which case the default callout behavior will be used, which will show both the `title` and the `description`, if provided.                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| `description:` <br/> `string`               | The description of the marker. This is only used if the <Marker /> component has no children that are a `<Callout />`, in which case the default callout behavior will be used, which will show both the `title` and the `description`, if provided.                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| `image:` <br/> `ReactNative.Image.Source.t` | A custom image to be used as the marker's icon. Only local image resources are allowed to be used.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| `icon:` <br/> `ReactNative.Image.Source.t`  | Marker icon to render (equivalent to `icon` property of GMSMarker Class).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| `pinColor:` <br/> `string`                  | If no custom marker view or custom image is provided, the platform default pin will be used, which can be customized by this color. Ignored if a custom marker is being used.<br/><br/> For Android, the set of available colors is limited. Unsupported colors will fall back to red. See [#887](https://github.com/react-community/react-native-maps/issues/887) for more information.                                                                                                                                                                                                                                                                                                                            |
| `coordinate:` <br/> `LatLng.t`              | The coordinate for the marker.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| `centerOffset:` <br/> `point`               | The offset (in points) at which to display the view.<br/><br/> By default, the center point of an annotation view is placed at the coordinate point of the associated annotation. You can use this property to reposition the annotation view as needed. This x and y offset values are measured in points. Positive offset values move the annotation view down and to the right, while negative values move it up and to the left.<br/><br/> For Google Maps, see the `anchor` prop. <br /> <br /> **default value**: `{x: 0, y: 0}`                                                                                                                                                                              |
| `calloutOffset:` <br/> `point`              | The offset (in points) at which to place the callout bubble.<br/><br/> This property determines the additional distance by which to move the callout bubble. When this property is set to (0, 0), the anchor point of the callout bubble is placed on the top-center point of the marker view’s frame. Specifying positive offset values moves the callout bubble down and to the right, while specifying negative values moves it up and to the left.<br/><br/> For Google Maps, see the `calloutAnchor` prop. <br /> <br /> **default value**: `{x: 0, y: 0}`                                                                                                                                                     |
| `anchor:` <br/> `point`                     | Sets the anchor point for the marker.<br/><br/> The anchor specifies the point in the icon image that is anchored to the marker's position on the Earth's surface.<br/><br/> The anchor point is specified in the continuous space `[0.0, 1.0] x [0.0, 1.0]`, where `(0, 0)` is the top-left corner of the image, and `(1, 1)` is the bottom-right corner. The anchoring point in a W x H image is the nearest discrete grid point in a (W + 1) x (H + 1) grid, obtained by scaling the then rounding. For example, in a 4 x 2 image, the anchor point (0.7, 0.6) resolves to the grid point at (3, 1).<br/><br/> For MapKit on iOS, see the `centerOffset` prop. <br /> <br /> **default value**: `{x: 0.5, y: 1}` |
| `calloutAnchor:` <br/> `point`              | Specifies the point in the marker image at which to anchor the callout when it is displayed. This is specified in the same coordinate system as the anchor. See the `anchor` prop for more details.<br/><br/> The default is the top middle of the image.<br/><br/> For MapKit on iOS, see the `calloutOffset` prop. <br /> <br /> **default value**: `{x: 0.5, y: 0}`                                                                                                                                                                                                                                                                                                                                              |
| `flat:` <br/> `bool`                        | Sets whether this marker should be flat against the map true or a billboard facing the camera. <br /> <br /> **default value**: `false`                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| `identifier:` <br/> `string`                | An identifier used to reference this marker at a later date.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| `rotation:` <br/> `float`                   | A float number indicating marker's rotation angle, in degrees. <br /> <br /> **default value**: `0.0`                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| `draggable:` <br/> `bool`                   | In JS, this is a non-value based prop. Set `draggable=bool` to enable dragging (re-positioning) and omit to disable it.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| `tracksViewChanges:` <br/> `bool`           | Sets whether this marker should track view changes. It's recommended to turn it off whenever it's possible to improve custom marker performance. <br /> <br /> **default value**: `true`                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| `tracksInfoWindowChanges:` <br/> `bool`     | _iOS Google Maps only_ <br /> Sets whether this marker should track view changes in info window. Enabling it will let marker change content of info window after first render pass, but will lead to decreased performance, so it's recommended to disable it whenever you don't need it. <br /> <br /> **default value**: `false`                                                                                                                                                                                                                                                                                                                                                                                  |
| `stopPropagation:` <br/> `bool`             | _iOS only_ <br /> Sets whether this marker should propagate `onPress` events. If enabled, `onPress` event will not be triggered for the parent `MapView`. **Note**: Android does not propagate `onPress` events. See [#1132](https://github.com/react-community/react-native-maps/issues/1132) for more information. <br /> <br /> **default value**: `false`                                                                                                                                                                                                                                                                                                                                                       |
| `opacity:` <br/> `float`                    | The marker's opacity between `0.0` and `1.0`. <br /> <br /> **default value**: `1.0`                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |

## Events

Events may return no data (`unit`) or `ReactNative.Event.syntheticEvent(copos)`.

### Events returning `unit`

Handler function needs to be of type `unit => unit`.

| Event Name       | Notes                                                        |
| ---------------- | ------------------------------------------------------------ |
| `onCalloutPress` | Callback that is called when the user taps the callout view. |

### Events returning `ReactNative.Event.syntheticEvent(copos)`

Handler function needs to be of type
`ReactNative.Event.syntheticEvent(copos) => unit`. You will need to use the `##`
accessor for each individual key within the function specified. For example:

```reason
onPress={e => Js.Console.warn(e##nativeEvent)}
```

| Event Name    | Notes                                                                                                                                             |
| ------------- | ------------------------------------------------------------------------------------------------------------------------------------------------- |
| `onPress`     | Callback that is called when the user presses on the marker                                                                                       |
| `onSelect`    | _iOS only_ <br/> Callback that is called when the user selects the marker, before the callout is shown.                                           |
| `onDeselect`  | _iOS only_ <br/> Callback that is called when the marker is deselected, before the callout is hidden.                                             |
| `onDragStart` | Callback that is called when the user initiates a drag on this marker (if it is draggable)                                                        |
| `onDrag`      | Callback called continuously as the marker is dragged                                                                                             |
| `onDragEnd`   | Callback that is called when a drag on this marker finishes. This is usually the point you will want to setState on the marker's coordinate again |

## Methods

| Method Name <br/> and <br/> Type Signature                              | Notes                                                                                                                                                            |
| ----------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `showCallout:` <br/> `(element, unit) => unit`                          | Shows the callout for this marker                                                                                                                                |
| `hideCallout:` <br/> `(element, unit) => unit`                          | Hides the callout for this marker                                                                                                                                |
| `redrawCallout:` <br/> `(element, unit) => unit`                        | Causes a redraw of the marker's callout. Useful for Google Maps on iOS. <br/> **Note**: iOS only.                                                                |
| `animateMarkerToCoordinate:` <br/> `(element, LatLng.t, float) => unit` | _Android only_ <br /> Animates marker movement. Coordinate should be specified as `LatLng.t` and the duration for the animation should be specified as a `float` |
| `redraw:` <br/> `(element, unit) => unit`                               | Causes a redraw of the marker. Useful when there are updates to the marker and `tracksViewChanges` comes with a cost that is too high.                           |

## Child Components

Child components can be added within a `Marker` and rendered content will
replace the marker symbol. This is a way of creating custom markers and allowing
use of native SVGs.

Example:

```reason
open ReactNative;
open ReactNativeMaps;

<Marker
	...
>
  <View style=Style.style(~backgroundColor=Color.red, ~padding=10.0->Style.dp, ())>
    <Text>"SF" -> React.string</Text>
  </View>
</Marker>
```
